@@ -17,7 +17,7 @@ import (
 
 	"github.com/DCSO/fever/types"
 
-	"github.com/garyburd/redigo/redis"
+	"github.com/gomodule/redigo/redis"
 	log "github.com/sirupsen/logrus"
 	"github.com/stvp/tempredis"
 )
